/*****************************************************************************/
/* Copyright (C) 2003-2012, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/*                                                                           */
/*  This file is part of the JRS MPEG-7 Library.                             */
/*  http://mpeg-7.joanneum.at                                                */
/*                                                                           */
/*  JRS MPEG-7 Library is free software: you can redistribute it and/or      */
/*  modify it under the terms of the GNU Lesser General Public License       */
/*  (LGPL) as published by the Free Software Foundation, either version 3    */
/*  of the License, or (at your option) any later version.                   */
/*                                                                           */
/*  JRS MPEG-7 Library is distributed in the hope that it will be useful,    */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of           */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the             */
/*  GNU Lesser General Public License for more details.                      */
/*                                                                           */
/*  You should have received a copy of the GNU Lesser General Public License */
/*  along with this library. If not, see <http://www.gnu.org/licenses/>.     */
/*****************************************************************************/


// ClassType_H.template
#ifndef _699MP7JRSCREATIONTYPE_H
#define _699MP7JRSCREATIONTYPE_H

#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsCreationTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"


// no includefile for extension defined 
// file Mp7JrsCreationType_ExtInclude.h


#include "Mp7JrsDSType.h"
#include "Mp7JrsMpeg7BaseType.h"
class IMp7JrsCreationType;
class IMp7JrsCreationType_Abstract_CollectionType;
class IMp7JrsCreationType_CopyrightString_CollectionType;
class IMp7JrsCreationType_CreationCoordinates_CollectionType;
class IMp7JrsCreationType_CreationTool_CollectionType;
class IMp7JrsCreationType_Creator_CollectionType;
class IMp7JrsCreationType_Title_CollectionType;
class IMp7JrsDSType;
class IMp7JrsDSType_Header_CollectionType;
class IMp7JrsdurationType;
class IMp7JrsmediaDurationType;
class IMp7JrsTitleMediaType;
class IMp7JrsxPathRefType;
typedef Mp7JrsPtr< IMp7JrsCreationType_Abstract_CollectionType > Mp7JrsCreationType_Abstract_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsCreationType_CopyrightString_CollectionType > Mp7JrsCreationType_CopyrightString_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsCreationType_CreationCoordinates_CollectionType > Mp7JrsCreationType_CreationCoordinates_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsCreationType_CreationTool_CollectionType > Mp7JrsCreationType_CreationTool_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsCreationType_Creator_CollectionType > Mp7JrsCreationType_Creator_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsCreationType_Title_CollectionType > Mp7JrsCreationType_Title_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsCreationType> Mp7JrsCreationPtr;
typedef Mp7JrsPtr< IMp7JrsDSType > Mp7JrsDSPtr;
typedef Mp7JrsPtr< IMp7JrsDSType_Header_CollectionType > Mp7JrsDSType_Header_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsdurationType > Mp7JrsdurationPtr;
typedef Mp7JrsPtr< IMp7JrsmediaDurationType > Mp7JrsmediaDurationPtr;
typedef Mp7JrsPtr< IMp7JrsTitleMediaType > Mp7JrsTitleMediaPtr;
typedef Mp7JrsPtr< IMp7JrsxPathRefType > Mp7JrsxPathRefPtr;

/** 
 * Generated interface IMp7JrsCreationType for class Mp7JrsCreationType<br>
 * Located at: mpeg7-v2.xsd, line 5369<br>
 * Classified: Class<br>
 * Derived from: DSType (Class)<br>
 */
class MP7JRS_EXPORT IMp7JrsCreationType 
 :
		public IMp7JrsDSType
{
public:
	// TODO: make these protected?
	IMp7JrsCreationType();
	virtual ~IMp7JrsCreationType();
		/** @name Sequence

		 */
		//@{
	/**
	 * Get Title element.
	 * @return Mp7JrsCreationType_Title_CollectionPtr
	 */
	virtual Mp7JrsCreationType_Title_CollectionPtr GetTitle() const = 0;

	/**
	 * Set Title element.
	 * @param item const Mp7JrsCreationType_Title_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetTitle(const Mp7JrsCreationType_Title_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/**
	 * Get TitleMedia element.
	 * @return Mp7JrsTitleMediaPtr
	 */
	virtual Mp7JrsTitleMediaPtr GetTitleMedia() const = 0;

	virtual bool IsValidTitleMedia() const = 0;

	/**
	 * Set TitleMedia element.
	 * @param item const Mp7JrsTitleMediaPtr &
	 */
	virtual void SetTitleMedia(const Mp7JrsTitleMediaPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate TitleMedia element.
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateTitleMedia() = 0;

	/**
	 * Get Abstract element.
	 * @return Mp7JrsCreationType_Abstract_CollectionPtr
	 */
	virtual Mp7JrsCreationType_Abstract_CollectionPtr GetAbstract() const = 0;

	/**
	 * Set Abstract element.
	 * @param item const Mp7JrsCreationType_Abstract_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetAbstract(const Mp7JrsCreationType_Abstract_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/**
	 * Get Creator element.
	 * @return Mp7JrsCreationType_Creator_CollectionPtr
	 */
	virtual Mp7JrsCreationType_Creator_CollectionPtr GetCreator() const = 0;

	/**
	 * Set Creator element.
	 * @param item const Mp7JrsCreationType_Creator_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetCreator(const Mp7JrsCreationType_Creator_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/**
	 * Get CreationCoordinates element.
	 * @return Mp7JrsCreationType_CreationCoordinates_CollectionPtr
	 */
	virtual Mp7JrsCreationType_CreationCoordinates_CollectionPtr GetCreationCoordinates() const = 0;

	/**
	 * Set CreationCoordinates element.
	 * @param item const Mp7JrsCreationType_CreationCoordinates_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetCreationCoordinates(const Mp7JrsCreationType_CreationCoordinates_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/**
	 * Get CreationTool element.
	 * @return Mp7JrsCreationType_CreationTool_CollectionPtr
	 */
	virtual Mp7JrsCreationType_CreationTool_CollectionPtr GetCreationTool() const = 0;

	/**
	 * Set CreationTool element.
	 * @param item const Mp7JrsCreationType_CreationTool_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetCreationTool(const Mp7JrsCreationType_CreationTool_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/**
	 * Get CopyrightString element.
	 * @return Mp7JrsCreationType_CopyrightString_CollectionPtr
	 */
	virtual Mp7JrsCreationType_CopyrightString_CollectionPtr GetCopyrightString() const = 0;

	/**
	 * Set CopyrightString element.
	 * @param item const Mp7JrsCreationType_CopyrightString_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetCopyrightString(const Mp7JrsCreationType_CopyrightString_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

		//@}
	/**
	 * Get id attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return XMLCh *
	 */
	virtual XMLCh * Getid() const = 0;

	/**
	 * Get id attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool Existid() const = 0;

	/**
	 * Set id attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item XMLCh *
	 */
	virtual void Setid(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate id attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void Invalidateid() = 0;

	/**
	 * Get timeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsxPathRefPtr
	 */
	virtual Mp7JrsxPathRefPtr GettimeBase() const = 0;

	/**
	 * Get timeBase attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExisttimeBase() const = 0;

	/**
	 * Set timeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsxPathRefPtr &
	 */
	virtual void SettimeBase(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate timeBase attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatetimeBase() = 0;

	/**
	 * Get timeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsdurationPtr
	 */
	virtual Mp7JrsdurationPtr GettimeUnit() const = 0;

	/**
	 * Get timeUnit attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExisttimeUnit() const = 0;

	/**
	 * Set timeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsdurationPtr &
	 */
	virtual void SettimeUnit(const Mp7JrsdurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate timeUnit attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatetimeUnit() = 0;

	/**
	 * Get mediaTimeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsxPathRefPtr
	 */
	virtual Mp7JrsxPathRefPtr GetmediaTimeBase() const = 0;

	/**
	 * Get mediaTimeBase attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExistmediaTimeBase() const = 0;

	/**
	 * Set mediaTimeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsxPathRefPtr &
	 */
	virtual void SetmediaTimeBase(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate mediaTimeBase attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatemediaTimeBase() = 0;

	/**
	 * Get mediaTimeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsmediaDurationPtr
	 */
	virtual Mp7JrsmediaDurationPtr GetmediaTimeUnit() const = 0;

	/**
	 * Get mediaTimeUnit attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExistmediaTimeUnit() const = 0;

	/**
	 * Set mediaTimeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsmediaDurationPtr &
	 */
	virtual void SetmediaTimeUnit(const Mp7JrsmediaDurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate mediaTimeUnit attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatemediaTimeUnit() = 0;

		/** @name Sequence

		 */
		//@{
	/**
	 * Get Header element.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsDSType_Header_CollectionPtr
	 */
	virtual Mp7JrsDSType_Header_CollectionPtr GetHeader() const = 0;

	/**
	 * Set Header element.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsDSType_Header_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetHeader(const Mp7JrsDSType_Header_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

		//@}
	/**
	 * Gets or creates Mp7JrsNodePtr child elements of CreationType.
	 * Currently this type contains 8 child elements of type "Mp7JrsNodePtr".

	 * <ul>
	 * <li>urn:mpeg:mpeg7:schema:2004:Header</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:Title</li>
	 * <li>TitleMedia</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:Abstract</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:Creator</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:CreationCoordinates</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:CreationTool</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:CopyrightString</li>
	 * </ul>
	 * 
	 * Supported XPath expressions for GetOrCreateFromXPath
	 * 
	 * \par<code>/</code>
	 *  - Get the root of this node.
	 * \par<code>..</code>
	 *  - This feature is experimental.
	 *  - Get the ancestor (parent node), or an empty list if the node already is the root node.
	 * 
	 * \par<code>A</code> 
	 * - Select all child elements named <code>A</code>.
	 * - In case of no element, create a new one.
	 * - For collections: all subsequent XPath expressions are applied on all collection items (e.g. <code>A/B</code> query or create, childnodes <code>B</code> of all <code>A</code>s). 
	 * \par<code>A[i]</code>
	 * - Select the <code>i</code>th child element of all <code>A</code>.
	 * - Please note, that XPath indexes start at 1.
	 * - If there is no such <code>i</code>th element, try to create a new one at index <code>i</code>.
	 * - Single elements require <code>i</code> to be 1 otherwise an exception is thrown.
	 * - For collections, <code>i</code> must not exceed the number of existing items +1 (appending is allowed, filling gaps not).
	 * - If the index is too high, a <code>MissingElementException</code> is thrown, and you can extract the last valid index. (Example: If a collection contains 2 elements and you are requesting the 4th element).
	 * 
	 * \par <code>A[\@xsi:type="T"]</code>
	 *	 - Select all child elements named <code>A</code> of type <code>T</code>.
	 *	 - Currently only typenames without namespace are recognised.
	 *	 - If there is no such element, create and append a new one.
	 * \par <code>A[i][\@xsi:type="T"]</code>
	 *	 - Select the <code>i</code>th child element named <code>A</code>, which must be of type <code>T</code>.
	 *	 - If there is no such element at index <code>i</code>, a new one is created and inserted (appended).
	 * \par <code>A[\@xsi:type="T"][i]</code>
	 *	 - Out of all child elements named <code>A</code> of type <code>T</code>, take the <code>i</code>th one.
	 *	 - If there is no such element at index <code>i</code>, create and append one.
	 * 
	 * \par <code>A[last()]</code>
	 *	 - Select the last child element named <code>A</code>.
	 *	 - In case of no element, create a new one.
	 * \par <code>A[last()][\@xsi:type="T"]</code>
	 *	 - Select the last child element named <code>A</code>, which must be of type <code>T</code>.
	 *	 - For collections: in case of no such type, create and append a new one.
	 *	 - For single elements: if an element with different type exists, return the empty list.
	 * 
	 * \par <code>A[\@xsi:type="T"][last()]</code>
	 *	 - Out of all child elements named <code>A</code> of type <code>T</code>, take the last one.
	 *	 - For collections: in case of no such type, create and append a new one.
	 *	 - For single elements: if an element with different type exists, return the empty list.
	 * 
	 * \par <code>A[position() \> last()]</code>
	 *	 - Force creation of a child element named <code>A</code> with its default type.
	 *	 - For collections: create and append the default element.
	 *	 - For single elements: if any element exists, an exception is thrown.
	 *
	 * \par <code>A[position() \> last()][\@xsi:type="T"]</code>
	 *	 - Force creation of a child element named <code>A</code> of type <code>T</code>.
	 *	 - For collections: create and append the element.
	 *	 - For single elements: if any element exists, an exception is thrown.
	 *
	 * \par <code>A[\@xsi:type="T"][position() \> last()]</code>
	 *	 - Force creation of a child element named <code>A</code> of type <code>T</code>.
	 *	 - Behaves the same way as the previous expression.
	 * 
	 * 
	 * Supported XPath expressions for GetFromXPath<br>
	 * The same expressions like GetOrCreateFromXPath plus
	 * \par <code>A[position() \< i] </code>
	 *	 - Select all child elements named <code>A</code> at indexes lower than <code>i</code>.
	 *	 - <code>i</code> must be greater than -1, otherwise an exception is thrown.
	 * \par <code>A[position() \> i] </code>
	 *	 - Select all child elements named <code>A</code> at indexes greater than <code>i</code>.
	 *	 - <code>i</code> must be greater than -1, otherwise an exception is thrown.
	 * \par <code>A[position() \> i | position() \< j] </code>
	 *	 - Select all child elements named <code>A</code> at indexes greater than <code>i</code> and lower than <code>j</code>.
	 *	 - <code>i</code> and <code>j</code> must be greater than -1, otherwise an exception is thrown.
	 *	 - If <code>i</code> is greater than <code>j</code> then an empty list is returned.
	 *
	 * These three expressions can be combined with the <code>\@xsi:type</code> attribute to get a more restricted query.
	 *
	 * @param xpath  the xpath expression to get or create.
	 * @param client the ID in case of locking.
	 * @return the appropriate subelement node list. Can be empty in case of incompatible name/type/index settings.
	 */
	// xpath: mandatory
	// client: optional
	virtual Mp7JrsNodeEnum GetOrCreateFromXPath(const XMLCh *xpath, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT, Mp7JrsXPathCreation flag = MP7JRS_FORCECREATE, Mp7JrsXPathParseContext * context = NULL) = 0;

	
// no includefile for extension defined 
// file Mp7JrsCreationType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsCreationType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsCreationType<br>
 * Located at: mpeg7-v2.xsd, line 5369<br>
 * Classified: Class<br>
 * Derived from: DSType (Class)<br>
 * Defined in mpeg7-v2.xsd, line 5369.<br>
 */
class MP7JRS_EXPORT Mp7JrsCreationType :
		public IMp7JrsCreationType
{
	friend class Mp7JrsCreationTypeFactory; // constructs objects

public:
	/*
	 * Retrieves the base class of Mp7JrsCreationType
	 
	 * @return Mp7JrsPtr< Mp7JrsDSType >
	 */
	virtual Mp7JrsPtr< Mp7JrsDSType > GetBase() const;
		/* @name Sequence

		 */
		//@{
	/*
	 * Get Title element.
	 * @return Mp7JrsCreationType_Title_CollectionPtr
	 */
	virtual Mp7JrsCreationType_Title_CollectionPtr GetTitle() const;

	/*
	 * Set Title element.
	 * @param item const Mp7JrsCreationType_Title_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetTitle(const Mp7JrsCreationType_Title_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	/*
	 * Get TitleMedia element.
	 * @return Mp7JrsTitleMediaPtr
	 */
	virtual Mp7JrsTitleMediaPtr GetTitleMedia() const;

	virtual bool IsValidTitleMedia() const;

	/*
	 * Set TitleMedia element.
	 * @param item const Mp7JrsTitleMediaPtr &
	 */
	virtual void SetTitleMedia(const Mp7JrsTitleMediaPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate TitleMedia element.
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateTitleMedia();

	/*
	 * Get Abstract element.
	 * @return Mp7JrsCreationType_Abstract_CollectionPtr
	 */
	virtual Mp7JrsCreationType_Abstract_CollectionPtr GetAbstract() const;

	/*
	 * Set Abstract element.
	 * @param item const Mp7JrsCreationType_Abstract_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetAbstract(const Mp7JrsCreationType_Abstract_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	/*
	 * Get Creator element.
	 * @return Mp7JrsCreationType_Creator_CollectionPtr
	 */
	virtual Mp7JrsCreationType_Creator_CollectionPtr GetCreator() const;

	/*
	 * Set Creator element.
	 * @param item const Mp7JrsCreationType_Creator_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetCreator(const Mp7JrsCreationType_Creator_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	/*
	 * Get CreationCoordinates element.
	 * @return Mp7JrsCreationType_CreationCoordinates_CollectionPtr
	 */
	virtual Mp7JrsCreationType_CreationCoordinates_CollectionPtr GetCreationCoordinates() const;

	/*
	 * Set CreationCoordinates element.
	 * @param item const Mp7JrsCreationType_CreationCoordinates_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetCreationCoordinates(const Mp7JrsCreationType_CreationCoordinates_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	/*
	 * Get CreationTool element.
	 * @return Mp7JrsCreationType_CreationTool_CollectionPtr
	 */
	virtual Mp7JrsCreationType_CreationTool_CollectionPtr GetCreationTool() const;

	/*
	 * Set CreationTool element.
	 * @param item const Mp7JrsCreationType_CreationTool_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetCreationTool(const Mp7JrsCreationType_CreationTool_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	/*
	 * Get CopyrightString element.
	 * @return Mp7JrsCreationType_CopyrightString_CollectionPtr
	 */
	virtual Mp7JrsCreationType_CopyrightString_CollectionPtr GetCopyrightString() const;

	/*
	 * Set CopyrightString element.
	 * @param item const Mp7JrsCreationType_CopyrightString_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetCopyrightString(const Mp7JrsCreationType_CopyrightString_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

		//@}
	/*
	 * Get id attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return XMLCh *
	 */
	virtual XMLCh * Getid() const;

	/*
	 * Get id attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool Existid() const;

	/*
	 * Set id attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item XMLCh *
	 */
	virtual void Setid(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate id attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void Invalidateid();

	/*
	 * Get timeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsxPathRefPtr
	 */
	virtual Mp7JrsxPathRefPtr GettimeBase() const;

	/*
	 * Get timeBase attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExisttimeBase() const;

	/*
	 * Set timeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsxPathRefPtr &
	 */
	virtual void SettimeBase(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate timeBase attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatetimeBase();

	/*
	 * Get timeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsdurationPtr
	 */
	virtual Mp7JrsdurationPtr GettimeUnit() const;

	/*
	 * Get timeUnit attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExisttimeUnit() const;

	/*
	 * Set timeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsdurationPtr &
	 */
	virtual void SettimeUnit(const Mp7JrsdurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate timeUnit attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatetimeUnit();

	/*
	 * Get mediaTimeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsxPathRefPtr
	 */
	virtual Mp7JrsxPathRefPtr GetmediaTimeBase() const;

	/*
	 * Get mediaTimeBase attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExistmediaTimeBase() const;

	/*
	 * Set mediaTimeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsxPathRefPtr &
	 */
	virtual void SetmediaTimeBase(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate mediaTimeBase attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatemediaTimeBase();

	/*
	 * Get mediaTimeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsmediaDurationPtr
	 */
	virtual Mp7JrsmediaDurationPtr GetmediaTimeUnit() const;

	/*
	 * Get mediaTimeUnit attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExistmediaTimeUnit() const;

	/*
	 * Set mediaTimeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsmediaDurationPtr &
	 */
	virtual void SetmediaTimeUnit(const Mp7JrsmediaDurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate mediaTimeUnit attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatemediaTimeUnit();

		/* @name Sequence

		 */
		//@{
	/*
	 * Get Header element.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsDSType_Header_CollectionPtr
	 */
	virtual Mp7JrsDSType_Header_CollectionPtr GetHeader() const;

	/*
	 * Set Header element.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsDSType_Header_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetHeader(const Mp7JrsDSType_Header_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

		//@}
	/*
	 * Gets or creates Mp7JrsNodePtr child elements of CreationType.
	 * Currently this type contains 8 child elements of type "Mp7JrsNodePtr".

	 * <ul>
	 * <li>urn:mpeg:mpeg7:schema:2004:Header</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:Title</li>
	 * <li>TitleMedia</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:Abstract</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:Creator</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:CreationCoordinates</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:CreationTool</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:CopyrightString</li>
	 * </ul>
	 * 
	 * Supported XPath expressions for GetOrCreateFromXPath
	 * 
	 * \par<code>/</code>
	 *  - Get the root of this node.
	 * \par<code>..</code>
	 *  - This feature is experimental.
	 *  - Get the ancestor (parent node), or an empty list if the node already is the root node.
	 * 
	 * \par<code>A</code> 
	 * - Select all child elements named <code>A</code>.
	 * - In case of no element, create a new one.
	 * - For collections: all subsequent XPath expressions are applied on all collection items (e.g. <code>A/B</code> query or create, childnodes <code>B</code> of all <code>A</code>s). 
	 * \par<code>A[i]</code>
	 * - Select the <code>i</code>th child element of all <code>A</code>.
	 * - Please note, that XPath indexes start at 1.
	 * - If there is no such <code>i</code>th element, try to create a new one at index <code>i</code>.
	 * - Single elements require <code>i</code> to be 1 otherwise an exception is thrown.
	 * - For collections, <code>i</code> must not exceed the number of existing items +1 (appending is allowed, filling gaps not).
	 * - If the index is too high, a <code>MissingElementException</code> is thrown, and you can extract the last valid index. (Example: If a collection contains 2 elements and you are requesting the 4th element).
	 * 
	 * \par <code>A[\@xsi:type="T"]</code>
	 *	 - Select all child elements named <code>A</code> of type <code>T</code>.
	 *	 - Currently only typenames without namespace are recognised.
	 *	 - If there is no such element, create and append a new one.
	 * \par <code>A[i][\@xsi:type="T"]</code>
	 *	 - Select the <code>i</code>th child element named <code>A</code>, which must be of type <code>T</code>.
	 *	 - If there is no such element at index <code>i</code>, a new one is created and inserted (appended).
	 * \par <code>A[\@xsi:type="T"][i]</code>
	 *	 - Out of all child elements named <code>A</code> of type <code>T</code>, take the <code>i</code>th one.
	 *	 - If there is no such element at index <code>i</code>, create and append one.
	 * 
	 * \par <code>A[last()]</code>
	 *	 - Select the last child element named <code>A</code>.
	 *	 - In case of no element, create a new one.
	 * \par <code>A[last()][\@xsi:type="T"]</code>
	 *	 - Select the last child element named <code>A</code>, which must be of type <code>T</code>.
	 *	 - For collections: in case of no such type, create and append a new one.
	 *	 - For single elements: if an element with different type exists, return the empty list.
	 * 
	 * \par <code>A[\@xsi:type="T"][last()]</code>
	 *	 - Out of all child elements named <code>A</code> of type <code>T</code>, take the last one.
	 *	 - For collections: in case of no such type, create and append a new one.
	 *	 - For single elements: if an element with different type exists, return the empty list.
	 * 
	 * \par <code>A[position() \> last()]</code>
	 *	 - Force creation of a child element named <code>A</code> with its default type.
	 *	 - For collections: create and append the default element.
	 *	 - For single elements: if any element exists, an exception is thrown.
	 *
	 * \par <code>A[position() \> last()][\@xsi:type="T"]</code>
	 *	 - Force creation of a child element named <code>A</code> of type <code>T</code>.
	 *	 - For collections: create and append the element.
	 *	 - For single elements: if any element exists, an exception is thrown.
	 *
	 * \par <code>A[\@xsi:type="T"][position() \> last()]</code>
	 *	 - Force creation of a child element named <code>A</code> of type <code>T</code>.
	 *	 - Behaves the same way as the previous expression.
	 * 
	 * 
	 * Supported XPath expressions for GetFromXPath<br>
	 * The same expressions like GetOrCreateFromXPath plus
	 * \par <code>A[position() \< i] </code>
	 *	 - Select all child elements named <code>A</code> at indexes lower than <code>i</code>.
	 *	 - <code>i</code> must be greater than -1, otherwise an exception is thrown.
	 * \par <code>A[position() \> i] </code>
	 *	 - Select all child elements named <code>A</code> at indexes greater than <code>i</code>.
	 *	 - <code>i</code> must be greater than -1, otherwise an exception is thrown.
	 * \par <code>A[position() \> i | position() \< j] </code>
	 *	 - Select all child elements named <code>A</code> at indexes greater than <code>i</code> and lower than <code>j</code>.
	 *	 - <code>i</code> and <code>j</code> must be greater than -1, otherwise an exception is thrown.
	 *	 - If <code>i</code> is greater than <code>j</code> then an empty list is returned.
	 *
	 * These three expressions can be combined with the <code>\@xsi:type</code> attribute to get a more restricted query.
	 *
	 * @param xpath  the xpath expression to get or create.
	 * @param client the ID in case of locking.
	 * @return the appropriate subelement node list. Can be empty in case of incompatible name/type/index settings.
	 */
	// xpath: mandatory
	// client: optional
	virtual Mp7JrsNodeEnum GetOrCreateFromXPath(const XMLCh *xpath, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT, Mp7JrsXPathCreation flag = MP7JRS_FORCECREATE, Mp7JrsXPathParseContext * context = NULL);

	

	/* Get the class name.
	 * @return The name of this class.
	 */
	virtual XMLCh * ToText() const;

	/* Parse this type.
	 * @param txt buffer to parse from.
	 * @return true if parsing was successful, false otherwise.
	 */
	virtual bool Parse(const XMLCh * const txt);

	/* Serialialize this object to a DOM tree.
	 * @param doc DOM document.
	 * @param parent Parent node in DOM tree.
	 */
	virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

	/* Deserialize this object from a DOM tree.
	 * @param doc DOM document.
	 * @param parent Parent element in DOM tree.
	 * @param current Current element in DOM tree.
	 */
	virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

	/* Creates and inserts a Childnode of the specified Type
	 * @param type The tag type of the child to be created (tag name).
	 * @param xsitype The xsi type of the child to be created if available.
	 * @return the created child with the correct dynamic type for the specified type.
	 */
	virtual Mp7JrsNodePtr CreateChild(const XMLCh * const elementname, const XMLCh * const xsitype);
		 
// no includefile for extension defined 
// file Mp7JrsCreationType_ExtMyMethodDef.h


public:

	virtual ~Mp7JrsCreationType();

protected:
	Mp7JrsCreationType();
	virtual void DeepCopy(const Mp7JrsNodePtr &original);

	virtual Mp7JrsNodeEnum GetAllChildElements() const;

	virtual Mp7JrsNodePtr GetBaseRoot();
	virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:

	// Base Class
	Mp7JrsPtr< Mp7JrsDSType > m_Base;

	Mp7JrsCreationType_Title_CollectionPtr m_Title;
	Mp7JrsTitleMediaPtr m_TitleMedia;
	bool m_TitleMedia_Exist; // For optional elements 
	Mp7JrsCreationType_Abstract_CollectionPtr m_Abstract;
	Mp7JrsCreationType_Creator_CollectionPtr m_Creator;
	Mp7JrsCreationType_CreationCoordinates_CollectionPtr m_CreationCoordinates;
	Mp7JrsCreationType_CreationTool_CollectionPtr m_CreationTool;
	Mp7JrsCreationType_CopyrightString_CollectionPtr m_CopyrightString;

// no includefile for extension defined 
// file Mp7JrsCreationType_ExtMyPropDef.h


public:
	virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
	void Cleanup();
};

#endif // _699MP7JRSCREATIONTYPE_H

