/*****************************************************************************/
/* Copyright (C) 2003-2012, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/*                                                                           */
/*  This file is part of the JRS MPEG-7 Library.                             */
/*  http://mpeg-7.joanneum.at                                                */
/*                                                                           */
/*  JRS MPEG-7 Library is free software: you can redistribute it and/or      */
/*  modify it under the terms of the GNU Lesser General Public License       */
/*  (LGPL) as published by the Free Software Foundation, either version 3    */
/*  of the License, or (at your option) any later version.                   */
/*                                                                           */
/*  JRS MPEG-7 Library is distributed in the hope that it will be useful,    */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of           */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the             */
/*  GNU Lesser General Public License for more details.                      */
/*                                                                           */
/*  You should have received a copy of the GNU Lesser General Public License */
/*  along with this library. If not, see <http://www.gnu.org/licenses/>.     */
/*****************************************************************************/


// ClassType_H.template
#ifndef _991MP7JRSGEOMETRICDISTRIBUTIONTYPE_H
#define _991MP7JRSGEOMETRICDISTRIBUTIONTYPE_H

#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsGeometricDistributionTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"


// no includefile for extension defined 
// file Mp7JrsGeometricDistributionType_ExtInclude.h


#include "Mp7JrsDiscreteDistributionType.h"
#include "Mp7JrsDSType.h"
#include "Mp7JrsModelType.h"
#include "Mp7JrsMpeg7BaseType.h"
#include "Mp7JrsProbabilityDistributionType.h"
#include "Mp7JrsProbabilityModelType.h"
class IMp7JrsDiscreteDistributionType;
class IMp7JrsDoubleMatrixType;
class IMp7JrsDSType_Header_CollectionType;
class IMp7JrsdurationType;
class IMp7JrsGeometricDistributionType;
class IMp7JrsmediaDurationType;
class IMp7JrsProbabilityDistributionType_Cumulant_CollectionType;
class IMp7JrsProbabilityDistributionType_Moment_CollectionType;
class IMp7JrsxPathRefType;
class IMp7JrszeroToOneType;
typedef Mp7JrsPtr< IMp7JrsDiscreteDistributionType > Mp7JrsDiscreteDistributionPtr;
typedef Mp7JrsPtr< IMp7JrsDoubleMatrixType > Mp7JrsDoubleMatrixPtr;
typedef Mp7JrsPtr< IMp7JrsDSType_Header_CollectionType > Mp7JrsDSType_Header_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsdurationType > Mp7JrsdurationPtr;
typedef Mp7JrsPtr< IMp7JrsGeometricDistributionType> Mp7JrsGeometricDistributionPtr;
typedef Mp7JrsPtr< IMp7JrsmediaDurationType > Mp7JrsmediaDurationPtr;
typedef Mp7JrsPtr< IMp7JrsProbabilityDistributionType_Cumulant_CollectionType > Mp7JrsProbabilityDistributionType_Cumulant_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsProbabilityDistributionType_Moment_CollectionType > Mp7JrsProbabilityDistributionType_Moment_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsxPathRefType > Mp7JrsxPathRefPtr;
typedef Mp7JrsPtr< IMp7JrszeroToOneType > Mp7JrszeroToOnePtr;

/** 
 * Generated interface IMp7JrsGeometricDistributionType for class Mp7JrsGeometricDistributionType<br>
 * Located at: mpeg7-v2.xsd, line 8365<br>
 * Classified: Class<br>
 * Derived from: DiscreteDistributionType (Class)<br>
 */
class MP7JRS_EXPORT IMp7JrsGeometricDistributionType 
 :
		public IMp7JrsDiscreteDistributionType
{
public:
	// TODO: make these protected?
	IMp7JrsGeometricDistributionType();
	virtual ~IMp7JrsGeometricDistributionType();
		/** @name Sequence

		 */
		//@{
	/**
	 * Get SuccessProbability element.
	 * @return Mp7JrsDoubleMatrixPtr
	 */
	virtual Mp7JrsDoubleMatrixPtr GetSuccessProbability() const = 0;

	/**
	 * Set SuccessProbability element.
	 * @param item const Mp7JrsDoubleMatrixPtr &
	 */
	// Mandatory			
	virtual void SetSuccessProbability(const Mp7JrsDoubleMatrixPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

		//@}
	/**
	 * Get dim attribute.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return unsigned
	 */
	virtual unsigned Getdim() const = 0;

	/**
	 * Get dim attribute validity information.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool Existdim() const = 0;

	/**
	 * Set dim attribute.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item unsigned
	 */
	virtual void Setdim(unsigned item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate dim attribute.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void Invalidatedim() = 0;

		/** @name Sequence

		 */
		//@{
	/**
	 * Get Mean element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsDoubleMatrixPtr
	 */
	virtual Mp7JrsDoubleMatrixPtr GetMean() const = 0;

	virtual bool IsValidMean() const = 0;

	/**
	 * Set Mean element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsDoubleMatrixPtr &
	 */
	virtual void SetMean(const Mp7JrsDoubleMatrixPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate Mean element.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateMean() = 0;

	/**
	 * Get Variance element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsDoubleMatrixPtr
	 */
	virtual Mp7JrsDoubleMatrixPtr GetVariance() const = 0;

	virtual bool IsValidVariance() const = 0;

	/**
	 * Set Variance element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsDoubleMatrixPtr &
	 */
	virtual void SetVariance(const Mp7JrsDoubleMatrixPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate Variance element.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateVariance() = 0;

	/**
	 * Get Min element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsDoubleMatrixPtr
	 */
	virtual Mp7JrsDoubleMatrixPtr GetMin() const = 0;

	virtual bool IsValidMin() const = 0;

	/**
	 * Set Min element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsDoubleMatrixPtr &
	 */
	virtual void SetMin(const Mp7JrsDoubleMatrixPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate Min element.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateMin() = 0;

	/**
	 * Get Max element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsDoubleMatrixPtr
	 */
	virtual Mp7JrsDoubleMatrixPtr GetMax() const = 0;

	virtual bool IsValidMax() const = 0;

	/**
	 * Set Max element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsDoubleMatrixPtr &
	 */
	virtual void SetMax(const Mp7JrsDoubleMatrixPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate Max element.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateMax() = 0;

	/**
	 * Get Mode element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsDoubleMatrixPtr
	 */
	virtual Mp7JrsDoubleMatrixPtr GetMode() const = 0;

	virtual bool IsValidMode() const = 0;

	/**
	 * Set Mode element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsDoubleMatrixPtr &
	 */
	virtual void SetMode(const Mp7JrsDoubleMatrixPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate Mode element.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateMode() = 0;

	/**
	 * Get Median element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsDoubleMatrixPtr
	 */
	virtual Mp7JrsDoubleMatrixPtr GetMedian() const = 0;

	virtual bool IsValidMedian() const = 0;

	/**
	 * Set Median element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsDoubleMatrixPtr &
	 */
	virtual void SetMedian(const Mp7JrsDoubleMatrixPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate Median element.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateMedian() = 0;

	/**
	 * Get Moment element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsProbabilityDistributionType_Moment_CollectionPtr
	 */
	virtual Mp7JrsProbabilityDistributionType_Moment_CollectionPtr GetMoment() const = 0;

	/**
	 * Set Moment element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsProbabilityDistributionType_Moment_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetMoment(const Mp7JrsProbabilityDistributionType_Moment_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/**
	 * Get Cumulant element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsProbabilityDistributionType_Cumulant_CollectionPtr
	 */
	virtual Mp7JrsProbabilityDistributionType_Cumulant_CollectionPtr GetCumulant() const = 0;

	/**
	 * Set Cumulant element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsProbabilityDistributionType_Cumulant_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetCumulant(const Mp7JrsProbabilityDistributionType_Cumulant_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

		//@}
	/**
	 * Get confidence attribute.
<br>
	 * (Inherited from Mp7JrsModelType)
	 * @return Mp7JrszeroToOnePtr
	 */
	virtual Mp7JrszeroToOnePtr Getconfidence() const = 0;

	/**
	 * Get confidence attribute validity information.
	 * (Inherited from Mp7JrsModelType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool Existconfidence() const = 0;

	/**
	 * Set confidence attribute.
<br>
	 * (Inherited from Mp7JrsModelType)
	 * @param item const Mp7JrszeroToOnePtr &
	 */
	virtual void Setconfidence(const Mp7JrszeroToOnePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate confidence attribute.
	 * (Inherited from Mp7JrsModelType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void Invalidateconfidence() = 0;

	/**
	 * Get reliability attribute.
<br>
	 * (Inherited from Mp7JrsModelType)
	 * @return Mp7JrszeroToOnePtr
	 */
	virtual Mp7JrszeroToOnePtr Getreliability() const = 0;

	/**
	 * Get reliability attribute validity information.
	 * (Inherited from Mp7JrsModelType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool Existreliability() const = 0;

	/**
	 * Set reliability attribute.
<br>
	 * (Inherited from Mp7JrsModelType)
	 * @param item const Mp7JrszeroToOnePtr &
	 */
	virtual void Setreliability(const Mp7JrszeroToOnePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate reliability attribute.
	 * (Inherited from Mp7JrsModelType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void Invalidatereliability() = 0;

	/**
	 * Get id attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return XMLCh *
	 */
	virtual XMLCh * Getid() const = 0;

	/**
	 * Get id attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool Existid() const = 0;

	/**
	 * Set id attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item XMLCh *
	 */
	virtual void Setid(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate id attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void Invalidateid() = 0;

	/**
	 * Get timeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsxPathRefPtr
	 */
	virtual Mp7JrsxPathRefPtr GettimeBase() const = 0;

	/**
	 * Get timeBase attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExisttimeBase() const = 0;

	/**
	 * Set timeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsxPathRefPtr &
	 */
	virtual void SettimeBase(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate timeBase attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatetimeBase() = 0;

	/**
	 * Get timeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsdurationPtr
	 */
	virtual Mp7JrsdurationPtr GettimeUnit() const = 0;

	/**
	 * Get timeUnit attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExisttimeUnit() const = 0;

	/**
	 * Set timeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsdurationPtr &
	 */
	virtual void SettimeUnit(const Mp7JrsdurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate timeUnit attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatetimeUnit() = 0;

	/**
	 * Get mediaTimeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsxPathRefPtr
	 */
	virtual Mp7JrsxPathRefPtr GetmediaTimeBase() const = 0;

	/**
	 * Get mediaTimeBase attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExistmediaTimeBase() const = 0;

	/**
	 * Set mediaTimeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsxPathRefPtr &
	 */
	virtual void SetmediaTimeBase(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate mediaTimeBase attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatemediaTimeBase() = 0;

	/**
	 * Get mediaTimeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsmediaDurationPtr
	 */
	virtual Mp7JrsmediaDurationPtr GetmediaTimeUnit() const = 0;

	/**
	 * Get mediaTimeUnit attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExistmediaTimeUnit() const = 0;

	/**
	 * Set mediaTimeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsmediaDurationPtr &
	 */
	virtual void SetmediaTimeUnit(const Mp7JrsmediaDurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate mediaTimeUnit attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatemediaTimeUnit() = 0;

		/** @name Sequence

		 */
		//@{
	/**
	 * Get Header element.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsDSType_Header_CollectionPtr
	 */
	virtual Mp7JrsDSType_Header_CollectionPtr GetHeader() const = 0;

	/**
	 * Set Header element.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsDSType_Header_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetHeader(const Mp7JrsDSType_Header_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

		//@}
	/**
	 * Gets or creates Mp7JrsNodePtr child elements of GeometricDistributionType.
	 * Currently this type contains 10 child elements of type "Mp7JrsNodePtr".

	 * <ul>
	 * <li>urn:mpeg:mpeg7:schema:2004:Header</li>
	 * <li>Mean</li>
	 * <li>Variance</li>
	 * <li>Min</li>
	 * <li>Max</li>
	 * <li>Mode</li>
	 * <li>Median</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:Moment</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:Cumulant</li>
	 * <li>SuccessProbability</li>
	 * </ul>
	 * 
	 * Supported XPath expressions for GetOrCreateFromXPath
	 * 
	 * \par<code>/</code>
	 *  - Get the root of this node.
	 * \par<code>..</code>
	 *  - This feature is experimental.
	 *  - Get the ancestor (parent node), or an empty list if the node already is the root node.
	 * 
	 * \par<code>A</code> 
	 * - Select all child elements named <code>A</code>.
	 * - In case of no element, create a new one.
	 * - For collections: all subsequent XPath expressions are applied on all collection items (e.g. <code>A/B</code> query or create, childnodes <code>B</code> of all <code>A</code>s). 
	 * \par<code>A[i]</code>
	 * - Select the <code>i</code>th child element of all <code>A</code>.
	 * - Please note, that XPath indexes start at 1.
	 * - If there is no such <code>i</code>th element, try to create a new one at index <code>i</code>.
	 * - Single elements require <code>i</code> to be 1 otherwise an exception is thrown.
	 * - For collections, <code>i</code> must not exceed the number of existing items +1 (appending is allowed, filling gaps not).
	 * - If the index is too high, a <code>MissingElementException</code> is thrown, and you can extract the last valid index. (Example: If a collection contains 2 elements and you are requesting the 4th element).
	 * 
	 * \par <code>A[\@xsi:type="T"]</code>
	 *	 - Select all child elements named <code>A</code> of type <code>T</code>.
	 *	 - Currently only typenames without namespace are recognised.
	 *	 - If there is no such element, create and append a new one.
	 * \par <code>A[i][\@xsi:type="T"]</code>
	 *	 - Select the <code>i</code>th child element named <code>A</code>, which must be of type <code>T</code>.
	 *	 - If there is no such element at index <code>i</code>, a new one is created and inserted (appended).
	 * \par <code>A[\@xsi:type="T"][i]</code>
	 *	 - Out of all child elements named <code>A</code> of type <code>T</code>, take the <code>i</code>th one.
	 *	 - If there is no such element at index <code>i</code>, create and append one.
	 * 
	 * \par <code>A[last()]</code>
	 *	 - Select the last child element named <code>A</code>.
	 *	 - In case of no element, create a new one.
	 * \par <code>A[last()][\@xsi:type="T"]</code>
	 *	 - Select the last child element named <code>A</code>, which must be of type <code>T</code>.
	 *	 - For collections: in case of no such type, create and append a new one.
	 *	 - For single elements: if an element with different type exists, return the empty list.
	 * 
	 * \par <code>A[\@xsi:type="T"][last()]</code>
	 *	 - Out of all child elements named <code>A</code> of type <code>T</code>, take the last one.
	 *	 - For collections: in case of no such type, create and append a new one.
	 *	 - For single elements: if an element with different type exists, return the empty list.
	 * 
	 * \par <code>A[position() \> last()]</code>
	 *	 - Force creation of a child element named <code>A</code> with its default type.
	 *	 - For collections: create and append the default element.
	 *	 - For single elements: if any element exists, an exception is thrown.
	 *
	 * \par <code>A[position() \> last()][\@xsi:type="T"]</code>
	 *	 - Force creation of a child element named <code>A</code> of type <code>T</code>.
	 *	 - For collections: create and append the element.
	 *	 - For single elements: if any element exists, an exception is thrown.
	 *
	 * \par <code>A[\@xsi:type="T"][position() \> last()]</code>
	 *	 - Force creation of a child element named <code>A</code> of type <code>T</code>.
	 *	 - Behaves the same way as the previous expression.
	 * 
	 * 
	 * Supported XPath expressions for GetFromXPath<br>
	 * The same expressions like GetOrCreateFromXPath plus
	 * \par <code>A[position() \< i] </code>
	 *	 - Select all child elements named <code>A</code> at indexes lower than <code>i</code>.
	 *	 - <code>i</code> must be greater than -1, otherwise an exception is thrown.
	 * \par <code>A[position() \> i] </code>
	 *	 - Select all child elements named <code>A</code> at indexes greater than <code>i</code>.
	 *	 - <code>i</code> must be greater than -1, otherwise an exception is thrown.
	 * \par <code>A[position() \> i | position() \< j] </code>
	 *	 - Select all child elements named <code>A</code> at indexes greater than <code>i</code> and lower than <code>j</code>.
	 *	 - <code>i</code> and <code>j</code> must be greater than -1, otherwise an exception is thrown.
	 *	 - If <code>i</code> is greater than <code>j</code> then an empty list is returned.
	 *
	 * These three expressions can be combined with the <code>\@xsi:type</code> attribute to get a more restricted query.
	 *
	 * @param xpath  the xpath expression to get or create.
	 * @param client the ID in case of locking.
	 * @return the appropriate subelement node list. Can be empty in case of incompatible name/type/index settings.
	 */
	// xpath: mandatory
	// client: optional
	virtual Mp7JrsNodeEnum GetOrCreateFromXPath(const XMLCh *xpath, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT, Mp7JrsXPathCreation flag = MP7JRS_FORCECREATE, Mp7JrsXPathParseContext * context = NULL) = 0;

	
// no includefile for extension defined 
// file Mp7JrsGeometricDistributionType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsGeometricDistributionType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsGeometricDistributionType<br>
 * Located at: mpeg7-v2.xsd, line 8365<br>
 * Classified: Class<br>
 * Derived from: DiscreteDistributionType (Class)<br>
 * Defined in mpeg7-v2.xsd, line 8365.<br>
 */
class MP7JRS_EXPORT Mp7JrsGeometricDistributionType :
		public IMp7JrsGeometricDistributionType
{
	friend class Mp7JrsGeometricDistributionTypeFactory; // constructs objects

public:
	/*
	 * Retrieves the base class of Mp7JrsGeometricDistributionType
	 
	 * @return Mp7JrsPtr< Mp7JrsDiscreteDistributionType >
	 */
	virtual Mp7JrsPtr< Mp7JrsDiscreteDistributionType > GetBase() const;
		/* @name Sequence

		 */
		//@{
	/*
	 * Get SuccessProbability element.
	 * @return Mp7JrsDoubleMatrixPtr
	 */
	virtual Mp7JrsDoubleMatrixPtr GetSuccessProbability() const;

	/*
	 * Set SuccessProbability element.
	 * @param item const Mp7JrsDoubleMatrixPtr &
	 */
	// Mandatory			
	virtual void SetSuccessProbability(const Mp7JrsDoubleMatrixPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

		//@}
	/*
	 * Get dim attribute.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return unsigned
	 */
	virtual unsigned Getdim() const;

	/*
	 * Get dim attribute validity information.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool Existdim() const;

	/*
	 * Set dim attribute.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item unsigned
	 */
	virtual void Setdim(unsigned item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate dim attribute.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void Invalidatedim();

		/* @name Sequence

		 */
		//@{
	/*
	 * Get Mean element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsDoubleMatrixPtr
	 */
	virtual Mp7JrsDoubleMatrixPtr GetMean() const;

	virtual bool IsValidMean() const;

	/*
	 * Set Mean element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsDoubleMatrixPtr &
	 */
	virtual void SetMean(const Mp7JrsDoubleMatrixPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate Mean element.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateMean();

	/*
	 * Get Variance element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsDoubleMatrixPtr
	 */
	virtual Mp7JrsDoubleMatrixPtr GetVariance() const;

	virtual bool IsValidVariance() const;

	/*
	 * Set Variance element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsDoubleMatrixPtr &
	 */
	virtual void SetVariance(const Mp7JrsDoubleMatrixPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate Variance element.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateVariance();

	/*
	 * Get Min element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsDoubleMatrixPtr
	 */
	virtual Mp7JrsDoubleMatrixPtr GetMin() const;

	virtual bool IsValidMin() const;

	/*
	 * Set Min element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsDoubleMatrixPtr &
	 */
	virtual void SetMin(const Mp7JrsDoubleMatrixPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate Min element.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateMin();

	/*
	 * Get Max element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsDoubleMatrixPtr
	 */
	virtual Mp7JrsDoubleMatrixPtr GetMax() const;

	virtual bool IsValidMax() const;

	/*
	 * Set Max element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsDoubleMatrixPtr &
	 */
	virtual void SetMax(const Mp7JrsDoubleMatrixPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate Max element.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateMax();

	/*
	 * Get Mode element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsDoubleMatrixPtr
	 */
	virtual Mp7JrsDoubleMatrixPtr GetMode() const;

	virtual bool IsValidMode() const;

	/*
	 * Set Mode element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsDoubleMatrixPtr &
	 */
	virtual void SetMode(const Mp7JrsDoubleMatrixPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate Mode element.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateMode();

	/*
	 * Get Median element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsDoubleMatrixPtr
	 */
	virtual Mp7JrsDoubleMatrixPtr GetMedian() const;

	virtual bool IsValidMedian() const;

	/*
	 * Set Median element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsDoubleMatrixPtr &
	 */
	virtual void SetMedian(const Mp7JrsDoubleMatrixPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate Median element.
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateMedian();

	/*
	 * Get Moment element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsProbabilityDistributionType_Moment_CollectionPtr
	 */
	virtual Mp7JrsProbabilityDistributionType_Moment_CollectionPtr GetMoment() const;

	/*
	 * Set Moment element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsProbabilityDistributionType_Moment_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetMoment(const Mp7JrsProbabilityDistributionType_Moment_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	/*
	 * Get Cumulant element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @return Mp7JrsProbabilityDistributionType_Cumulant_CollectionPtr
	 */
	virtual Mp7JrsProbabilityDistributionType_Cumulant_CollectionPtr GetCumulant() const;

	/*
	 * Set Cumulant element.
<br>
	 * (Inherited from Mp7JrsProbabilityDistributionType)
	 * @param item const Mp7JrsProbabilityDistributionType_Cumulant_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetCumulant(const Mp7JrsProbabilityDistributionType_Cumulant_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

		//@}
	/*
	 * Get confidence attribute.
<br>
	 * (Inherited from Mp7JrsModelType)
	 * @return Mp7JrszeroToOnePtr
	 */
	virtual Mp7JrszeroToOnePtr Getconfidence() const;

	/*
	 * Get confidence attribute validity information.
	 * (Inherited from Mp7JrsModelType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool Existconfidence() const;

	/*
	 * Set confidence attribute.
<br>
	 * (Inherited from Mp7JrsModelType)
	 * @param item const Mp7JrszeroToOnePtr &
	 */
	virtual void Setconfidence(const Mp7JrszeroToOnePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate confidence attribute.
	 * (Inherited from Mp7JrsModelType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void Invalidateconfidence();

	/*
	 * Get reliability attribute.
<br>
	 * (Inherited from Mp7JrsModelType)
	 * @return Mp7JrszeroToOnePtr
	 */
	virtual Mp7JrszeroToOnePtr Getreliability() const;

	/*
	 * Get reliability attribute validity information.
	 * (Inherited from Mp7JrsModelType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool Existreliability() const;

	/*
	 * Set reliability attribute.
<br>
	 * (Inherited from Mp7JrsModelType)
	 * @param item const Mp7JrszeroToOnePtr &
	 */
	virtual void Setreliability(const Mp7JrszeroToOnePtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate reliability attribute.
	 * (Inherited from Mp7JrsModelType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void Invalidatereliability();

	/*
	 * Get id attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return XMLCh *
	 */
	virtual XMLCh * Getid() const;

	/*
	 * Get id attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool Existid() const;

	/*
	 * Set id attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item XMLCh *
	 */
	virtual void Setid(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate id attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void Invalidateid();

	/*
	 * Get timeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsxPathRefPtr
	 */
	virtual Mp7JrsxPathRefPtr GettimeBase() const;

	/*
	 * Get timeBase attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExisttimeBase() const;

	/*
	 * Set timeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsxPathRefPtr &
	 */
	virtual void SettimeBase(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate timeBase attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatetimeBase();

	/*
	 * Get timeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsdurationPtr
	 */
	virtual Mp7JrsdurationPtr GettimeUnit() const;

	/*
	 * Get timeUnit attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExisttimeUnit() const;

	/*
	 * Set timeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsdurationPtr &
	 */
	virtual void SettimeUnit(const Mp7JrsdurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate timeUnit attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatetimeUnit();

	/*
	 * Get mediaTimeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsxPathRefPtr
	 */
	virtual Mp7JrsxPathRefPtr GetmediaTimeBase() const;

	/*
	 * Get mediaTimeBase attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExistmediaTimeBase() const;

	/*
	 * Set mediaTimeBase attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsxPathRefPtr &
	 */
	virtual void SetmediaTimeBase(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate mediaTimeBase attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatemediaTimeBase();

	/*
	 * Get mediaTimeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsmediaDurationPtr
	 */
	virtual Mp7JrsmediaDurationPtr GetmediaTimeUnit() const;

	/*
	 * Get mediaTimeUnit attribute validity information.
	 * (Inherited from Mp7JrsDSType)
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool ExistmediaTimeUnit() const;

	/*
	 * Set mediaTimeUnit attribute.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsmediaDurationPtr &
	 */
	virtual void SetmediaTimeUnit(const Mp7JrsmediaDurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate mediaTimeUnit attribute.
	 * (Inherited from Mp7JrsDSType)
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidatemediaTimeUnit();

		/* @name Sequence

		 */
		//@{
	/*
	 * Get Header element.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @return Mp7JrsDSType_Header_CollectionPtr
	 */
	virtual Mp7JrsDSType_Header_CollectionPtr GetHeader() const;

	/*
	 * Set Header element.
<br>
	 * (Inherited from Mp7JrsDSType)
	 * @param item const Mp7JrsDSType_Header_CollectionPtr &
	 */
	// Mandatory collection
	virtual void SetHeader(const Mp7JrsDSType_Header_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

		//@}
	/*
	 * Gets or creates Mp7JrsNodePtr child elements of GeometricDistributionType.
	 * Currently this type contains 10 child elements of type "Mp7JrsNodePtr".

	 * <ul>
	 * <li>urn:mpeg:mpeg7:schema:2004:Header</li>
	 * <li>Mean</li>
	 * <li>Variance</li>
	 * <li>Min</li>
	 * <li>Max</li>
	 * <li>Mode</li>
	 * <li>Median</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:Moment</li>
	 * <li>urn:mpeg:mpeg7:schema:2004:Cumulant</li>
	 * <li>SuccessProbability</li>
	 * </ul>
	 * 
	 * Supported XPath expressions for GetOrCreateFromXPath
	 * 
	 * \par<code>/</code>
	 *  - Get the root of this node.
	 * \par<code>..</code>
	 *  - This feature is experimental.
	 *  - Get the ancestor (parent node), or an empty list if the node already is the root node.
	 * 
	 * \par<code>A</code> 
	 * - Select all child elements named <code>A</code>.
	 * - In case of no element, create a new one.
	 * - For collections: all subsequent XPath expressions are applied on all collection items (e.g. <code>A/B</code> query or create, childnodes <code>B</code> of all <code>A</code>s). 
	 * \par<code>A[i]</code>
	 * - Select the <code>i</code>th child element of all <code>A</code>.
	 * - Please note, that XPath indexes start at 1.
	 * - If there is no such <code>i</code>th element, try to create a new one at index <code>i</code>.
	 * - Single elements require <code>i</code> to be 1 otherwise an exception is thrown.
	 * - For collections, <code>i</code> must not exceed the number of existing items +1 (appending is allowed, filling gaps not).
	 * - If the index is too high, a <code>MissingElementException</code> is thrown, and you can extract the last valid index. (Example: If a collection contains 2 elements and you are requesting the 4th element).
	 * 
	 * \par <code>A[\@xsi:type="T"]</code>
	 *	 - Select all child elements named <code>A</code> of type <code>T</code>.
	 *	 - Currently only typenames without namespace are recognised.
	 *	 - If there is no such element, create and append a new one.
	 * \par <code>A[i][\@xsi:type="T"]</code>
	 *	 - Select the <code>i</code>th child element named <code>A</code>, which must be of type <code>T</code>.
	 *	 - If there is no such element at index <code>i</code>, a new one is created and inserted (appended).
	 * \par <code>A[\@xsi:type="T"][i]</code>
	 *	 - Out of all child elements named <code>A</code> of type <code>T</code>, take the <code>i</code>th one.
	 *	 - If there is no such element at index <code>i</code>, create and append one.
	 * 
	 * \par <code>A[last()]</code>
	 *	 - Select the last child element named <code>A</code>.
	 *	 - In case of no element, create a new one.
	 * \par <code>A[last()][\@xsi:type="T"]</code>
	 *	 - Select the last child element named <code>A</code>, which must be of type <code>T</code>.
	 *	 - For collections: in case of no such type, create and append a new one.
	 *	 - For single elements: if an element with different type exists, return the empty list.
	 * 
	 * \par <code>A[\@xsi:type="T"][last()]</code>
	 *	 - Out of all child elements named <code>A</code> of type <code>T</code>, take the last one.
	 *	 - For collections: in case of no such type, create and append a new one.
	 *	 - For single elements: if an element with different type exists, return the empty list.
	 * 
	 * \par <code>A[position() \> last()]</code>
	 *	 - Force creation of a child element named <code>A</code> with its default type.
	 *	 - For collections: create and append the default element.
	 *	 - For single elements: if any element exists, an exception is thrown.
	 *
	 * \par <code>A[position() \> last()][\@xsi:type="T"]</code>
	 *	 - Force creation of a child element named <code>A</code> of type <code>T</code>.
	 *	 - For collections: create and append the element.
	 *	 - For single elements: if any element exists, an exception is thrown.
	 *
	 * \par <code>A[\@xsi:type="T"][position() \> last()]</code>
	 *	 - Force creation of a child element named <code>A</code> of type <code>T</code>.
	 *	 - Behaves the same way as the previous expression.
	 * 
	 * 
	 * Supported XPath expressions for GetFromXPath<br>
	 * The same expressions like GetOrCreateFromXPath plus
	 * \par <code>A[position() \< i] </code>
	 *	 - Select all child elements named <code>A</code> at indexes lower than <code>i</code>.
	 *	 - <code>i</code> must be greater than -1, otherwise an exception is thrown.
	 * \par <code>A[position() \> i] </code>
	 *	 - Select all child elements named <code>A</code> at indexes greater than <code>i</code>.
	 *	 - <code>i</code> must be greater than -1, otherwise an exception is thrown.
	 * \par <code>A[position() \> i | position() \< j] </code>
	 *	 - Select all child elements named <code>A</code> at indexes greater than <code>i</code> and lower than <code>j</code>.
	 *	 - <code>i</code> and <code>j</code> must be greater than -1, otherwise an exception is thrown.
	 *	 - If <code>i</code> is greater than <code>j</code> then an empty list is returned.
	 *
	 * These three expressions can be combined with the <code>\@xsi:type</code> attribute to get a more restricted query.
	 *
	 * @param xpath  the xpath expression to get or create.
	 * @param client the ID in case of locking.
	 * @return the appropriate subelement node list. Can be empty in case of incompatible name/type/index settings.
	 */
	// xpath: mandatory
	// client: optional
	virtual Mp7JrsNodeEnum GetOrCreateFromXPath(const XMLCh *xpath, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT, Mp7JrsXPathCreation flag = MP7JRS_FORCECREATE, Mp7JrsXPathParseContext * context = NULL);

	

	/* Get the class name.
	 * @return The name of this class.
	 */
	virtual XMLCh * ToText() const;

	/* Parse this type.
	 * @param txt buffer to parse from.
	 * @return true if parsing was successful, false otherwise.
	 */
	virtual bool Parse(const XMLCh * const txt);

	/* Serialialize this object to a DOM tree.
	 * @param doc DOM document.
	 * @param parent Parent node in DOM tree.
	 */
	virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

	/* Deserialize this object from a DOM tree.
	 * @param doc DOM document.
	 * @param parent Parent element in DOM tree.
	 * @param current Current element in DOM tree.
	 */
	virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

	/* Creates and inserts a Childnode of the specified Type
	 * @param type The tag type of the child to be created (tag name).
	 * @param xsitype The xsi type of the child to be created if available.
	 * @return the created child with the correct dynamic type for the specified type.
	 */
	virtual Mp7JrsNodePtr CreateChild(const XMLCh * const elementname, const XMLCh * const xsitype);
		 
// no includefile for extension defined 
// file Mp7JrsGeometricDistributionType_ExtMyMethodDef.h


public:

	virtual ~Mp7JrsGeometricDistributionType();

protected:
	Mp7JrsGeometricDistributionType();
	virtual void DeepCopy(const Mp7JrsNodePtr &original);

	virtual Mp7JrsNodeEnum GetAllChildElements() const;

	virtual Mp7JrsNodePtr GetBaseRoot();
	virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:

	// Base Class
	Mp7JrsPtr< Mp7JrsDiscreteDistributionType > m_Base;

	Mp7JrsDoubleMatrixPtr m_SuccessProbability;

// no includefile for extension defined 
// file Mp7JrsGeometricDistributionType_ExtMyPropDef.h


public:
	virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
	void Cleanup();
};

#endif // _991MP7JRSGEOMETRICDISTRIBUTIONTYPE_H

