/*****************************************************************************/
/* Copyright (C) 2003-2012, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/*                                                                           */
/*  This file is part of the JRS MPEG-7 Library.                             */
/*  http://mpeg-7.joanneum.at                                                */
/*                                                                           */
/*  JRS MPEG-7 Library is free software: you can redistribute it and/or      */
/*  modify it under the terms of the GNU Lesser General Public License       */
/*  (LGPL) as published by the Free Software Foundation, either version 3    */
/*  of the License, or (at your option) any later version.                   */
/*                                                                           */
/*  JRS MPEG-7 Library is distributed in the hope that it will be useful,    */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of           */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the             */
/*  GNU Lesser General Public License for more details.                      */
/*                                                                           */
/*  You should have received a copy of the GNU Lesser General Public License */
/*  along with this library. If not, see <http://www.gnu.org/licenses/>.     */
/*****************************************************************************/


// ValCollectionType_H

#ifndef _1057MP7JRSHIERARCHICALSUMMARYTYPE_COMPONENTS_COLLECTIONTYPE_H
#define _1057MP7JRSHIERARCHICALSUMMARYTYPE_COMPONENTS_COLLECTIONTYPE_H



#include "Mp7JrsDefines.h"
#include "Mp7JrsHierarchicalSummaryType_components_CollectionTypeFactory.h"
#include "Mp7JrsNode.h"
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>
#include "Mp7JrsValueVectorOf.h"

// no includefile for extension defined 
// file Mp7JrsHierarchicalSummaryType_components_CollectionType_ExtInclude.h


class IMp7JrsHierarchicalSummaryType_components_CollectionType;
typedef Mp7JrsPtr< IMp7JrsHierarchicalSummaryType_components_CollectionType> Mp7JrsHierarchicalSummaryType_components_CollectionPtr;

#include "Mp7JrsHierarchicalSummaryType_components_LocalType.h"


class Mp7JrsHierarchicalSummaryType_components_CollectionType;

/**
 * Generated interface IMp7JrsHierarchicalSummaryType_components_CollectionType for collection Mp7JrsHierarchicalSummaryType_components_CollectionType<br>
 * Located at: mpeg7-v2.xsd, line 7374<br>
 * Item type: HierarchicalSummaryType_components_LocalType (Enumeration)<br>
 */
class MP7JRS_EXPORT IMp7JrsHierarchicalSummaryType_components_CollectionType :
	public Mp7JrsNode
{
public:

	/** Initializes the collection.
	  * @param maxElems Number of elements for which memory is initially allocated.
	  * @param adoptElems if true, the collection is responsible for deallocating the memory used by its elements. if false, the application has to deallocate the collection elements.
	  */
	virtual void Initialize(unsigned int maxElems) = 0;

	/** Adds a new element to the collection.
	  * @param toAdd Element to be added.
	  */
	virtual void addElement(const Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration & toAdd, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/** Sets the element at the given position in the collection.
	  * @param toSet New value of the element.
	  * @param setAt Position of the element which shall be set.
	  */
	virtual void setElementAt(const Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration & toSet, unsigned int setAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/** Inserts the element at the given position in the collection.
	  * @param toInsert Element to be inserted.
	  * @param insertAt Position where the element will be inserted.
	  */
	virtual void insertElementAt(const Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration & toInsert, unsigned int insertAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/** Removes all elements from the collection.
	  */
	virtual void removeAllElements(Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/** Removes the specified element from the collection.
	  * @param removeAt Position of the element to be removed. 
	  */
	virtual void removeElementAt(unsigned int removeAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

	/** Check whether the collection contains the given element.
	  * @param toCheck Element to be checked for.
	  * @return True if the element is in the collection, false otherwise.
	  */
	virtual bool containsElement(const Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration &toCheck) = 0;

	/** Get the current capacity of the collection.
	  * @return The number of elements for which memory has been allocated.
	  */
	virtual unsigned int curCapacity() const = 0;

	/** Gets the element at the given position.
	  * @param Position of the element to be retrieved.
	  * @return the given element.
	  */
	virtual const Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration elementAt(unsigned int getAt) const = 0;

	/** Gets the element at the given position.
	  * @param Position of the element to be retrieved.
	  * @return The given element.
	  */
	virtual Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration elementAt(unsigned int getAt) = 0;

	/** Get the size of the collection.
	  * @return The current number of elements in the collection.
	  */
	virtual unsigned int size() const = 0;

	/** Allocate additional memory for the speciifed number of elements.
	  * @param length Number of elements to allcate memory for.
	  */
	virtual void ensureExtraCapacity(unsigned int length) = 0;

	// JRS: addition to Xerces collection
	/** Get the position of the specified element. 
	  * @param toCheck Element to be found in the collection.
	  * @return The position of the specified element or -1 if the element has not been found.
	  */
	virtual int elementIndexOf(const Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration &toCheck) const = 0;

};


class MP7JRS_EXPORT Mp7JrsHierarchicalSummaryType_components_CollectionType :
	public IMp7JrsHierarchicalSummaryType_components_CollectionType
{
	friend class Mp7JrsHierarchicalSummaryType_components_CollectionTypeFactory;

public:
	virtual void Initialize(unsigned int maxElems);

	virtual void addElement(const Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration & toAdd, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	virtual void setElementAt(const Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration & toSet, unsigned int setAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	virtual void insertElementAt(const Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration & toInsert, unsigned int insertAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	virtual void removeAllElements(Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	virtual void removeElementAt(unsigned int removeAt, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

	virtual bool containsElement(const Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration &toCheck);

	virtual unsigned int curCapacity() const;

	virtual const Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration elementAt(unsigned int getAt) const;

	virtual Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration elementAt(unsigned int getAt);

	virtual unsigned int size() const;

	virtual void ensureExtraCapacity(unsigned int length);

	/* Get the underlying array of the collection.
	  */
	virtual const Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration * rawData() const;

	virtual int elementIndexOf(const Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration &toCheck) const;

	/* Get the class name.
	 * @return The name of this class.
     */
	virtual XMLCh * ToText() const;
 
	/* Parse this type.
	 * @param txt buffer to parse from.
	 * @return true if parsing was successful, false otherwise.
	 */
	virtual bool Parse(const XMLCh * const txt);

    /* Parse the content from a string.  Note, this is purely for ComplexTypes with SimpleContent and SimpleTypes.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
	virtual bool ContentFromString(const XMLCh * const txt);

    /* Convert the content to string.  Note, this is purely for ComplexTypes with SimpleContent and SimpleTypes. All other types may return NULL or the class name.
     * @return the allocated XMLCh * if conversion was successful. The caller must free memory using Mp7JrsUtil.deallocate().
     */
	virtual XMLCh * ContentToString() const;


	/* Serialialize this object to a DOM tree.
	 * @param doc DOM document.
	 * @param parent Parent node in DOM tree.
	 */
	virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

	/* Deserialize this object from a DOM tree.
	 * @param doc DOM document.
	 * @param parent Parent element in DOM tree.
	 * @param current Current element in DOM tree.
	 */
	virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

// no includefile for extension defined 
// file Mp7JrsHierarchicalSummaryType_components_CollectionType_ExtMethodDef.h


	virtual ~Mp7JrsHierarchicalSummaryType_components_CollectionType();

protected:
	Mp7JrsHierarchicalSummaryType_components_CollectionType();
	virtual void DeepCopy(const Mp7JrsNodePtr &original);
	virtual Mp7JrsNodeEnum GetAllChildElements() const { return Mp7JrsNodeEnum(); }

private:
	Mp7JrsValueVectorOf <Mp7JrsHierarchicalSummaryType_components_LocalType::Enumeration> * m_Item;

// no includefile for extension defined 
// file Mp7JrsHierarchicalSummaryType_components_CollectionType_ExtPropDef.h


};

#endif // _1057MP7JRSHIERARCHICALSUMMARYTYPE_COMPONENTS_COLLECTIONTYPE_H
