/*****************************************************************************/
/* Copyright (C) 2003-2012, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/*                                                                           */
/*  This file is part of the JRS MPEG-7 Library.                             */
/*  http://mpeg-7.joanneum.at                                                */
/*                                                                           */
/*  JRS MPEG-7 Library is free software: you can redistribute it and/or      */
/*  modify it under the terms of the GNU Lesser General Public License       */
/*  (LGPL) as published by the Free Software Foundation, either version 3    */
/*  of the License, or (at your option) any later version.                   */
/*                                                                           */
/*  JRS MPEG-7 Library is distributed in the hope that it will be useful,    */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of           */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the             */
/*  GNU Lesser General Public License for more details.                      */
/*                                                                           */
/*  You should have received a copy of the GNU Lesser General Public License */
/*  along with this library. If not, see <http://www.gnu.org/licenses/>.     */
/*****************************************************************************/


// ClassType_H.template
#ifndef _1771MP7JRSPOSITIONTYPE_H
#define _1771MP7JRSPOSITIONTYPE_H

#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsPositionTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"


// no includefile for extension defined 
// file Mp7JrsPositionType_ExtInclude.h


class IMp7JrsExtentType;
class IMp7JrsPositionType;
typedef Mp7JrsPtr< IMp7JrsExtentType > Mp7JrsExtentPtr;
typedef Mp7JrsPtr< IMp7JrsPositionType> Mp7JrsPositionPtr;

/** 
 * Generated interface IMp7JrsPositionType for class Mp7JrsPositionType<br>
 * Located at: mpeg7-v2.xsd, line 7323<br>
 * Classified: Class<br>
 */
class MP7JRS_EXPORT IMp7JrsPositionType 
 :
		public Mp7JrsNode
{
public:
	// TODO: make these protected?
	IMp7JrsPositionType();
	virtual ~IMp7JrsPositionType();
	/**
	 * Get origin attribute.
	 * @return XMLCh *
	 */
	virtual XMLCh * Getorigin() const = 0;

	/**
	 * Get origin attribute validity information.
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool Existorigin() const = 0;

	/**
	 * Set origin attribute.
	 * @param item XMLCh *
	 */
	virtual void Setorigin(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate origin attribute.
	 
	 * (Validate it again by setting a value)
	 */
	virtual void Invalidateorigin() = 0;

		/** @name Sequence

		 */
		//@{
	/**
	 * Get Displacement element.
	 * @return Mp7JrsExtentPtr
	 */
	virtual Mp7JrsExtentPtr GetDisplacement() const = 0;

	virtual bool IsValidDisplacement() const = 0;

	/**
	 * Set Displacement element.
	 * @param item const Mp7JrsExtentPtr &
	 */
	virtual void SetDisplacement(const Mp7JrsExtentPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate Displacement element.
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateDisplacement() = 0;

	/**
	 * Get Direction element.
	 * @return Mp7JrsExtentPtr
	 */
	virtual Mp7JrsExtentPtr GetDirection() const = 0;

	virtual bool IsValidDirection() const = 0;

	/**
	 * Set Direction element.
	 * @param item const Mp7JrsExtentPtr &
	 */
	virtual void SetDirection(const Mp7JrsExtentPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


	/**
	 * Invalidate Direction element.
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateDirection() = 0;

		//@}
	/**
	 * Gets or creates Mp7JrsNodePtr child elements of PositionType.
	 * Currently this type contains 2 child elements of type "Mp7JrsNodePtr".

	 * <ul>
	 * <li>Displacement</li>
	 * <li>Direction</li>
	 * </ul>
	 * 
	 * Supported XPath expressions for GetOrCreateFromXPath
	 * 
	 * \par<code>/</code>
	 *  - Get the root of this node.
	 * \par<code>..</code>
	 *  - This feature is experimental.
	 *  - Get the ancestor (parent node), or an empty list if the node already is the root node.
	 * 
	 * \par<code>A</code> 
	 * - Select all child elements named <code>A</code>.
	 * - In case of no element, create a new one.
	 * - For collections: all subsequent XPath expressions are applied on all collection items (e.g. <code>A/B</code> query or create, childnodes <code>B</code> of all <code>A</code>s). 
	 * \par<code>A[i]</code>
	 * - Select the <code>i</code>th child element of all <code>A</code>.
	 * - Please note, that XPath indexes start at 1.
	 * - If there is no such <code>i</code>th element, try to create a new one at index <code>i</code>.
	 * - Single elements require <code>i</code> to be 1 otherwise an exception is thrown.
	 * - For collections, <code>i</code> must not exceed the number of existing items +1 (appending is allowed, filling gaps not).
	 * - If the index is too high, a <code>MissingElementException</code> is thrown, and you can extract the last valid index. (Example: If a collection contains 2 elements and you are requesting the 4th element).
	 * 
	 * \par <code>A[\@xsi:type="T"]</code>
	 *	 - Select all child elements named <code>A</code> of type <code>T</code>.
	 *	 - Currently only typenames without namespace are recognised.
	 *	 - If there is no such element, create and append a new one.
	 * \par <code>A[i][\@xsi:type="T"]</code>
	 *	 - Select the <code>i</code>th child element named <code>A</code>, which must be of type <code>T</code>.
	 *	 - If there is no such element at index <code>i</code>, a new one is created and inserted (appended).
	 * \par <code>A[\@xsi:type="T"][i]</code>
	 *	 - Out of all child elements named <code>A</code> of type <code>T</code>, take the <code>i</code>th one.
	 *	 - If there is no such element at index <code>i</code>, create and append one.
	 * 
	 * \par <code>A[last()]</code>
	 *	 - Select the last child element named <code>A</code>.
	 *	 - In case of no element, create a new one.
	 * \par <code>A[last()][\@xsi:type="T"]</code>
	 *	 - Select the last child element named <code>A</code>, which must be of type <code>T</code>.
	 *	 - For collections: in case of no such type, create and append a new one.
	 *	 - For single elements: if an element with different type exists, return the empty list.
	 * 
	 * \par <code>A[\@xsi:type="T"][last()]</code>
	 *	 - Out of all child elements named <code>A</code> of type <code>T</code>, take the last one.
	 *	 - For collections: in case of no such type, create and append a new one.
	 *	 - For single elements: if an element with different type exists, return the empty list.
	 * 
	 * \par <code>A[position() \> last()]</code>
	 *	 - Force creation of a child element named <code>A</code> with its default type.
	 *	 - For collections: create and append the default element.
	 *	 - For single elements: if any element exists, an exception is thrown.
	 *
	 * \par <code>A[position() \> last()][\@xsi:type="T"]</code>
	 *	 - Force creation of a child element named <code>A</code> of type <code>T</code>.
	 *	 - For collections: create and append the element.
	 *	 - For single elements: if any element exists, an exception is thrown.
	 *
	 * \par <code>A[\@xsi:type="T"][position() \> last()]</code>
	 *	 - Force creation of a child element named <code>A</code> of type <code>T</code>.
	 *	 - Behaves the same way as the previous expression.
	 * 
	 * 
	 * Supported XPath expressions for GetFromXPath<br>
	 * The same expressions like GetOrCreateFromXPath plus
	 * \par <code>A[position() \< i] </code>
	 *	 - Select all child elements named <code>A</code> at indexes lower than <code>i</code>.
	 *	 - <code>i</code> must be greater than -1, otherwise an exception is thrown.
	 * \par <code>A[position() \> i] </code>
	 *	 - Select all child elements named <code>A</code> at indexes greater than <code>i</code>.
	 *	 - <code>i</code> must be greater than -1, otherwise an exception is thrown.
	 * \par <code>A[position() \> i | position() \< j] </code>
	 *	 - Select all child elements named <code>A</code> at indexes greater than <code>i</code> and lower than <code>j</code>.
	 *	 - <code>i</code> and <code>j</code> must be greater than -1, otherwise an exception is thrown.
	 *	 - If <code>i</code> is greater than <code>j</code> then an empty list is returned.
	 *
	 * These three expressions can be combined with the <code>\@xsi:type</code> attribute to get a more restricted query.
	 *
	 * @param xpath  the xpath expression to get or create.
	 * @param client the ID in case of locking.
	 * @return the appropriate subelement node list. Can be empty in case of incompatible name/type/index settings.
	 */
	// xpath: mandatory
	// client: optional
	virtual Mp7JrsNodeEnum GetOrCreateFromXPath(const XMLCh *xpath, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT, Mp7JrsXPathCreation flag = MP7JRS_FORCECREATE, Mp7JrsXPathParseContext * context = NULL) = 0;

	
// no includefile for extension defined 
// file Mp7JrsPositionType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsPositionType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsPositionType<br>
 * Located at: mpeg7-v2.xsd, line 7323<br>
 * Classified: Class<br>
 * Defined in mpeg7-v2.xsd, line 7323.<br>
 */
class MP7JRS_EXPORT Mp7JrsPositionType :
		public IMp7JrsPositionType
{
	friend class Mp7JrsPositionTypeFactory; // constructs objects

public:
	/*
	 * Get origin attribute.
	 * @return XMLCh *
	 */
	virtual XMLCh * Getorigin() const;

	/*
	 * Get origin attribute validity information.
	 * @return true if attribute value is valid, false if not.
	 */
	virtual bool Existorigin() const;

	/*
	 * Set origin attribute.
	 * @param item XMLCh *
	 */
	virtual void Setorigin(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate origin attribute.
	 
	 * (Validate it again by setting a value)
	 */
	virtual void Invalidateorigin();

		/* @name Sequence

		 */
		//@{
	/*
	 * Get Displacement element.
	 * @return Mp7JrsExtentPtr
	 */
	virtual Mp7JrsExtentPtr GetDisplacement() const;

	virtual bool IsValidDisplacement() const;

	/*
	 * Set Displacement element.
	 * @param item const Mp7JrsExtentPtr &
	 */
	virtual void SetDisplacement(const Mp7JrsExtentPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate Displacement element.
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateDisplacement();

	/*
	 * Get Direction element.
	 * @return Mp7JrsExtentPtr
	 */
	virtual Mp7JrsExtentPtr GetDirection() const;

	virtual bool IsValidDirection() const;

	/*
	 * Set Direction element.
	 * @param item const Mp7JrsExtentPtr &
	 */
	virtual void SetDirection(const Mp7JrsExtentPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


	/*
	 * Invalidate Direction element.
	 
	 * (Validate it again by setting a value)
	 */
	virtual void InvalidateDirection();

		//@}
	/*
	 * Gets or creates Mp7JrsNodePtr child elements of PositionType.
	 * Currently this type contains 2 child elements of type "Mp7JrsNodePtr".

	 * <ul>
	 * <li>Displacement</li>
	 * <li>Direction</li>
	 * </ul>
	 * 
	 * Supported XPath expressions for GetOrCreateFromXPath
	 * 
	 * \par<code>/</code>
	 *  - Get the root of this node.
	 * \par<code>..</code>
	 *  - This feature is experimental.
	 *  - Get the ancestor (parent node), or an empty list if the node already is the root node.
	 * 
	 * \par<code>A</code> 
	 * - Select all child elements named <code>A</code>.
	 * - In case of no element, create a new one.
	 * - For collections: all subsequent XPath expressions are applied on all collection items (e.g. <code>A/B</code> query or create, childnodes <code>B</code> of all <code>A</code>s). 
	 * \par<code>A[i]</code>
	 * - Select the <code>i</code>th child element of all <code>A</code>.
	 * - Please note, that XPath indexes start at 1.
	 * - If there is no such <code>i</code>th element, try to create a new one at index <code>i</code>.
	 * - Single elements require <code>i</code> to be 1 otherwise an exception is thrown.
	 * - For collections, <code>i</code> must not exceed the number of existing items +1 (appending is allowed, filling gaps not).
	 * - If the index is too high, a <code>MissingElementException</code> is thrown, and you can extract the last valid index. (Example: If a collection contains 2 elements and you are requesting the 4th element).
	 * 
	 * \par <code>A[\@xsi:type="T"]</code>
	 *	 - Select all child elements named <code>A</code> of type <code>T</code>.
	 *	 - Currently only typenames without namespace are recognised.
	 *	 - If there is no such element, create and append a new one.
	 * \par <code>A[i][\@xsi:type="T"]</code>
	 *	 - Select the <code>i</code>th child element named <code>A</code>, which must be of type <code>T</code>.
	 *	 - If there is no such element at index <code>i</code>, a new one is created and inserted (appended).
	 * \par <code>A[\@xsi:type="T"][i]</code>
	 *	 - Out of all child elements named <code>A</code> of type <code>T</code>, take the <code>i</code>th one.
	 *	 - If there is no such element at index <code>i</code>, create and append one.
	 * 
	 * \par <code>A[last()]</code>
	 *	 - Select the last child element named <code>A</code>.
	 *	 - In case of no element, create a new one.
	 * \par <code>A[last()][\@xsi:type="T"]</code>
	 *	 - Select the last child element named <code>A</code>, which must be of type <code>T</code>.
	 *	 - For collections: in case of no such type, create and append a new one.
	 *	 - For single elements: if an element with different type exists, return the empty list.
	 * 
	 * \par <code>A[\@xsi:type="T"][last()]</code>
	 *	 - Out of all child elements named <code>A</code> of type <code>T</code>, take the last one.
	 *	 - For collections: in case of no such type, create and append a new one.
	 *	 - For single elements: if an element with different type exists, return the empty list.
	 * 
	 * \par <code>A[position() \> last()]</code>
	 *	 - Force creation of a child element named <code>A</code> with its default type.
	 *	 - For collections: create and append the default element.
	 *	 - For single elements: if any element exists, an exception is thrown.
	 *
	 * \par <code>A[position() \> last()][\@xsi:type="T"]</code>
	 *	 - Force creation of a child element named <code>A</code> of type <code>T</code>.
	 *	 - For collections: create and append the element.
	 *	 - For single elements: if any element exists, an exception is thrown.
	 *
	 * \par <code>A[\@xsi:type="T"][position() \> last()]</code>
	 *	 - Force creation of a child element named <code>A</code> of type <code>T</code>.
	 *	 - Behaves the same way as the previous expression.
	 * 
	 * 
	 * Supported XPath expressions for GetFromXPath<br>
	 * The same expressions like GetOrCreateFromXPath plus
	 * \par <code>A[position() \< i] </code>
	 *	 - Select all child elements named <code>A</code> at indexes lower than <code>i</code>.
	 *	 - <code>i</code> must be greater than -1, otherwise an exception is thrown.
	 * \par <code>A[position() \> i] </code>
	 *	 - Select all child elements named <code>A</code> at indexes greater than <code>i</code>.
	 *	 - <code>i</code> must be greater than -1, otherwise an exception is thrown.
	 * \par <code>A[position() \> i | position() \< j] </code>
	 *	 - Select all child elements named <code>A</code> at indexes greater than <code>i</code> and lower than <code>j</code>.
	 *	 - <code>i</code> and <code>j</code> must be greater than -1, otherwise an exception is thrown.
	 *	 - If <code>i</code> is greater than <code>j</code> then an empty list is returned.
	 *
	 * These three expressions can be combined with the <code>\@xsi:type</code> attribute to get a more restricted query.
	 *
	 * @param xpath  the xpath expression to get or create.
	 * @param client the ID in case of locking.
	 * @return the appropriate subelement node list. Can be empty in case of incompatible name/type/index settings.
	 */
	// xpath: mandatory
	// client: optional
	virtual Mp7JrsNodeEnum GetOrCreateFromXPath(const XMLCh *xpath, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT, Mp7JrsXPathCreation flag = MP7JRS_FORCECREATE, Mp7JrsXPathParseContext * context = NULL);

	

	/* Get the class name.
	 * @return The name of this class.
	 */
	virtual XMLCh * ToText() const;

	/* Parse this type.
	 * @param txt buffer to parse from.
	 * @return true if parsing was successful, false otherwise.
	 */
	virtual bool Parse(const XMLCh * const txt);

	/* Serialialize this object to a DOM tree.
	 * @param doc DOM document.
	 * @param parent Parent node in DOM tree.
	 */
	virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

	/* Deserialize this object from a DOM tree.
	 * @param doc DOM document.
	 * @param parent Parent element in DOM tree.
	 * @param current Current element in DOM tree.
	 */
	virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

	/* Creates and inserts a Childnode of the specified Type
	 * @param type The tag type of the child to be created (tag name).
	 * @param xsitype The xsi type of the child to be created if available.
	 * @return the created child with the correct dynamic type for the specified type.
	 */
	virtual Mp7JrsNodePtr CreateChild(const XMLCh * const elementname, const XMLCh * const xsitype);
		 
// no includefile for extension defined 
// file Mp7JrsPositionType_ExtMyMethodDef.h


public:

	virtual ~Mp7JrsPositionType();

protected:
	Mp7JrsPositionType();
	virtual void DeepCopy(const Mp7JrsNodePtr &original);

	virtual Mp7JrsNodeEnum GetAllChildElements() const;

	virtual Mp7JrsNodePtr GetBaseRoot();
	virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:
	XMLCh * m_origin;
	bool m_origin_Exist;


	Mp7JrsExtentPtr m_Displacement;
	bool m_Displacement_Exist; // For optional elements 
	Mp7JrsExtentPtr m_Direction;
	bool m_Direction_Exist; // For optional elements 

// no includefile for extension defined 
// file Mp7JrsPositionType_ExtMyPropDef.h


public:
	virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
	void Cleanup();
};

#endif // _1771MP7JRSPOSITIONTYPE_H

